@@ -1,5 +1,6 @@
 # -*-CPerl-*-
-# Last changed Time-stamp: <2015-01-27 16:56:46 mtw>
+# Last changed Time-stamp: <2015-02-05 15:34:24 mtw>
+
 
 package Bio::ViennaNGS::Util;
 
@@ -10,7 +11,8 @@ use warnings;
 use Data::Dumper;
 use File::Basename qw(fileparse);
 use IPC::Cmd qw(can_run run);
-use Path::Class;
+use Path::Class qw(dir file);
+use File::Path qw(make_path remove_tree);
 use Math::Round;
 use Carp;
 use Bio::ViennaNGS::FeatureChain;
@@ -18,9 +20,9 @@ use Bio::ViennaNGS::FeatureChain;
 our @ISA = qw(Exporter);
 our @EXPORT = ();
 
-our @EXPORT_OK = qw ( bed_or_bam2bw sortbed bed2bigBed
-		      unique_array kmer_enrichment extend_chain
-		      parse_bed6 fetch_chrom_sizes);
+our @EXPORT_OK = qw ( bed_or_bam2bw sortbed bed2bigBed unique_array
+		      kmer_enrichment extend_chain parse_bed6
+		      fetch_chrom_sizes mkdircheck rmdircheck);
 
 
 #^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^#
@@ -231,6 +233,7 @@ sub extend_chain{
   my $r	    = $_[3];
   my $u     = $_[4];
   my $d     = $_[5];
+  my $e     = $_[6];
   my $this_function = (caller(0))[3];
 
   ##return a new chain with extended coordinates
@@ -245,7 +248,7 @@ sub extend_chain{
     my $right  = 0;
     my $left   = 0;
     my $width  = nearest(1,($end-$start)/2);
-    $width = 0 if ($d > 0 || $u > 0);
+    $width = 0 if ($d > 0 || $u > 0 || !$e);
     if ($strand eq "+"){
       if ($d > 0){
 	$start = $end;
@@ -392,6 +395,42 @@ sub fetch_chrom_sizes{
   return(\%sizes);
 }
 
+sub mkdircheck {
+  my @dirstocreate=();
+  my $this_function = (caller(0))[3];
+  while(@_){
+    push @dirstocreate, shift(@_);
+  }
+  foreach (@dirstocreate){
+    my @total = split(/[\/\\]/,$_);
+    my $dir;
+    while(@total){
+      $dir = dir(shift(@total)) unless (defined $dir);
+      $dir = dir($dir,shift(@total));
+    }
+    return if (-d $dir);
+    make_path($dir,{ verbose => 1 }) or croak "Error creating directory: $dir\t$, in $this_function!";
+  }
+}
+
+sub rmdircheck {
+  my @dirstorm=();
+  my $this_function = (caller(0))[3];
+  while(@_){
+    push @dirstorm, shift(@_);
+  }
+  foreach (@dirstorm){
+    my @total = split(/[\/\\]/,$_);
+    my $dir='';
+    while(@total){
+      $dir = dir(shift(@total)) unless (defined $dir);
+      $dir = dir($dir,shift(@total));
+    }
+    return if (!-d $dir);
+    remove_tree($dir,{ verbose => 1 }) or croak "Error deleting directory: $dir, in $this_function!";
+  }
+}
+
 1;
 __END__
 
